Attribute VB_Name = "PCI_D64H"
Option Explicit

Global Const PARAMETER_IGNORED = &HFFFF

Global Const INVALID_CARD_ID = &HFF
Global Const INVALID_CARD_TYPE = &HFFFF

Global Const DOUBLE_BUFFER_MODE_ENABLE = &H01
Global Const DOUBLE_BUFFER_MODE_DISABLE = &H00

'Clock Mode
Global Const TRIG_SOURCE_INT_PACER = 1
Global Const TRIG_SOURCE_EXT_STROBE = 2
Global Const TRIG_SOURCE_HANDSHAKE = 3

'Virtual Sampling Rate for using external clock as the clock source
Global Const CLKSRC_EXT_SampRate = 10000

' Event type for the event message
Global Const DIEnd = 0
Global Const DOEnd = 0
Global Const DBEvent = 1
Global Const TrigEvent = 2

' Action the event message
Global Const ADD_NOTIFICATION = &H01
Global Const REMOVE_NOTIFICATION = &H00

' InputMode
Global Const DI_WAITING = &H02
Global Const DI_NOWAITING = &H00

Global Const DI_TRIG_RISING = &H04
Global Const DI_TRIG_FALLING = &H00

Global Const IREQ_RISING = &H08
Global Const IREQ_FALLING = &H00

' Output Mode
Global Const OREQ_ENABLE = &H10
Global Const OREQ_DISABLE = &H00

Global Const OTRIG_HIGH = &H20
Global Const OTRIG_LOW = &H00

' Synchronous Mode
Global Const SYNCH_OP = &H01
Global Const ASYNCH_OP = &H02

Global Const D64H_MaxCards = 16

' DI DO Status
Global Const DI_OVERRUN_STATUS = &H01
Global Const DO_UNDERRUN_STATUS = &H02

'Error Code
Global Const SUCCESS_NO_ERROR = 0

' indicate the unsuccessful routine-execution
Global Const ERROR_ROUTINE_FAIL_BASE = -100

Global Const ERROR_DEVICE_OPEN = -102
Global Const ERROR_DEVICE_CLOSE = -103
Global Const ERROR_DOUBLE_BUFFER_MODE = -104
Global Const ERROR_DI_CONFIG = -105
Global Const ERROR_DI_ASYNC_CLEAR = -106
Global Const ERROR_DI_ASYNC_CHECK = -107
Global Const ERROR_DI_ASYNC_HALF_READY = -108
Global Const ERROR_DI_PIO_READ = -109
Global Const ERROR_DO_CONFIG = -110
Global Const ERROR_DO_ASYNC_CLEAR = -111
Global Const ERROR_DO_ASYNC_CHECK = -112
Global Const ERROR_DO_PIO_READ = -113
Global Const ERROR_DO_PIO_WRITE = -114
Global Const ERROR_DO_PIO_LINE_WRITE = -115
Global Const ERROR_CONTINUE_DI_START = -116
Global Const ERROR_CONTINUE_DO_START = -117
Global Const ERROR_FIFO_STATUS_GET = -118
Global Const ERROR_DO_EXT_TRIGLINE_WRITE = -119


' Parameters Error
Global Const ERROR_INVALID_PARAMETER_BASE = -200
Global Const ERROR_INVALID_CARD_ID = -201
Global Const ERROR_INVALID_SCANNED_INDEX = -202
Global Const ERROR_CARD_ID_DUPLICATED = -203
Global Const ERROR_INVILID_DOUBLE_BUFFER_MODE = -204
Global Const ERROR_INVALID_PORT_LINE = -205
Global Const ERROR_INVALID_TRIGGER_SOURCE = -206
Global Const ERROR_INVALID_TRIGGER_ENABLE = -207
Global Const ERROR_INVALID_TRIGGER_POLARITY = -208
Global Const ERROR_INVALID_IREQ_POLARITY = -209
Global Const ERROR_INVALID_OTRIG_LEVEL = -210
Global Const ERROR_INVALID_OREG_ENABLE = -211
Global Const ERROR_INVALID_DOUBLE_BUFFER_MODE = -212
Global Const ERROR_INVALID_SYNCH_OP_MODE = -213
Global Const ERROR_SAMPLE_COUNT_IS_ODD = -214
Global Const ERROR_INVALID_DO_ITERATIONS = -215
Global Const ERROR_INVALID_EVENT_ACTION = -216
Global Const ERROR_INVALID_CALLBACK_ADDRESS = -217
Global Const ERROR_INVALID_BUFFER_ADDRESS = -218
Global Const ERROR_INVALID_PATTERN_SIZE = -219
Global Const ERROR_INVALID_FILTER_SETTING = -220
Global Const ERROR_INVALID_OREG_WIDTH = -221


' RunTime Error
Global Const ERROR_RUNTIME_BASE = -300
Global Const ERROR_NO_CARD_FOUND = -316
Global Const ERROR_MEMORY_MAP = -317
Global Const ERROR_MEMORY_UNMAP = -318
Global Const ERROR_ACCESS_VIOLATION_DATA_COPY = -319
Global Const ERROR_VARIABLE_PITCH_SET = -320
Global Const ERROR_DI_EVENT_ATTACH = -321
Global Const ERROR_DI_EVENT_DETACH = -322
Global Const ERROR_DO_EVENT_ATTACH = -323
Global Const ERROR_DO_EVENT_DETACH = -324
Global Const ERROR_EVENT_CREATE_FAILED = -325
Global Const ERROR_OVERLAP_EVENT_CREATE = -326

Global Const ERROR_IOCTL_FAILED = -361
Global Const ERROR_UNDEFINED_EXCEPTION = -362

' DIO RunTime Error
Global Const ERROR_DIO_RUNTIME_BASE = -500
Global Const ERROR_DEVICE_POWER_DOWN = -501
Global Const ERROR_INVALID_MAPPED_ADDRESS = -502
Global Const ERROR_BUFFER_NOT_ENOUGH = -503
Global Const ERROR_DMA_NOT_AVAILABLE = -504
Global Const ERROR_DMA_NOT_COMPLETE = -505
Global Const ERROR_DMA_NOT_STARTED = -506
Global Const ERROR_DMA_NOT_PAUSED = -507
Global Const ERROR_DMA_IS_PAUSED = -508
Global Const ERROR_DMA_IN_PROGRESS = -509
Global Const ERROR_INVALID_SAMPLE_RATE = -510
Global Const ERROR_SAMPLE_COUNT_TOO_LARGE = -511
Global Const ERROR_SYNCH_OP_WITH_DOUBLE_BUFFER_MODE = -512
Global Const ERROR_SYNCH_OP_WITH_ASYNC_CHECK = -513
Global Const ERROR_UNSUPPORTED_SETTING = -514
Global Const ERROR_PATTERN_OUT_WITH_DOUBLE_BUFFER_MODE = -515
Global Const ERROR_PATTERN_OUT_IN_PROGRESS = -516


Declare Function WaitForSingleObject Lib "kernel32" (ByVal hHandle As Long, ByVal Milliseconds As Long) As Long
'-------------------------------------------------------------------'
'  PCI-D64HU Function prototype                                     '
'-------------------------------------------------------------------'
'Operating System Functions
Declare Function d64h_scan Lib "D64HDLL.dll" (ByRef pCardNum As Integer, Optional pAvailCards As Byte = 0) As Integer
Declare Function d64h_cardinfo_get Lib "D64HDLL.dll" (ByVal ScannedIndex As Integer, ByRef pCardID As Byte) As Integer
Declare Function d64h_open Lib "D64HDLL.dll" (ByVal bCardID As Byte) As Integer
Declare Function d64h_close Lib "D64HDLL.dll" (ByVal bCardID As Byte) As Integer

'DI Functions
Declare Function d64h_di_config Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wTrigSource As Integer, ByVal wExtTrigEnable As Integer, ByVal wTrigPolarity As Integer, ByVal wI_REQ_Polarity As Integer) As Integer
Declare Function d64h_di_buffer_get Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pMemSize As Long, Optional ByRef pLowBufAddr As Long = 0, Optional ByRef pHighBufAddr As Long = 0) As Integer
Declare Function d64h_di_available_memory Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pMemSize As Long) As Integer


Declare Function d64h_di_async_check Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef Stopped As Byte, ByRef AccessCnt As Long) As Integer
Declare Function d64h_di_async_clear Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef AccessCnt As Long) As Integer
Declare Function d64h_di_async_dblbuf_mode Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wDblBufEnable As Integer) As Integer
Declare Function d64h_di_async_dblbuf_halfready Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pHalfReady As Byte, Optional ByRef pBufIndex As Integer = 0) As Integer
Declare Function d64h_di_async_dblbuf_transfer Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pBuffer As Long) As Integer

Declare Function d64h_di_readport Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pValue As Long) As Integer
Declare Function d64h_di_readline Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wLine As Integer, ByRef pValue As Integer) As Integer

Declare Function d64h_conti_readport Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pBuffer As Long, ByVal dwSampleCount As Long, ByVal fSampleRate As Double, ByVal wSyncMode As Integer) As Integer
Declare Function d64h_conti_di_status Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pStatus As Integer) As Integer

'DO Functions
Declare Function d64h_do_config Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wTrigSource As Integer, ByVal wO_REQ_Enable As Integer, ByVal wOutTrigHigh As Integer) As Integer
Declare Function d64h_do_available_memory Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pMemSize As Long) As Integer

Declare Function d64h_do_async_check Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef Stopped As Byte, ByRef AccessCnt As Long) As Integer
Declare Function d64h_do_async_clear Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef AccessCnt As Long) As Integer
Declare Function d64h_do_async_dblbuf_mode Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wDblBufEnable As Integer) As Integer
Declare Function d64h_do_async_dblbuf_halfready Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pHalfReady As Byte, Optional ByRef pBufIndex As Integer = 0) As Integer
Declare Function d64h_do_async_dblbuf_transfer Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pBuffer As Long) As Integer

Declare Function d64h_do_readport Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pValue As Long) As Integer
Declare Function d64h_do_readline Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wLine As Integer, ByRef pValue As Integer) As Integer
Declare Function d64h_do_writeport Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal dwValue As Long) As Integer
Declare Function d64h_do_writeline Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wLine As Integer, ByVal wValue As Integer) As Integer

Declare Function d64h_conti_writeport Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pBuffer As Long, ByVal dwSampleCount As Long, ByVal wIterations As Integer, ByVal fSampleRate As Double, ByVal wSyncMode As Integer) As Integer
Declare Function d64h_conti_pattern_write Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pBuffer As Long, ByVal dwSampleCount As Long, ByVal fSampleRate As Double) As Integer
Declare Function d64h_conti_do_status Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByRef pStatus As Integer) As Integer

Declare Function d64h_do_ext_trigline_write Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wValue As Integer) As Integer

Declare Function d64h_DI_filter_set Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wDIFilter As Integer) As Integer
Declare Function d64h_IREQ_filter_set Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wIREQFilter As Integer) As Integer
Declare Function d64h_OACK_filter_set Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wOACKFilter As Integer) As Integer
Declare Function d64h_ITRG_filter_set Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wITRGFilter As Integer) As Integer
Declare Function d64h_OREQ_width_set Lib "D64HDLL.dll" (ByVal bCardID As Byte, ByVal wOREQWidth As Integer) As Integer



